/// Header files.
#include <windows.h>
#include "gpio.h"
#include "CoProc.h"
#include "matrixkeypad.h"

/// MatrixKeypadScan() will scan for key-press until threadExit value is TRUE.
extern volatile BOOL threadExit;
 
int wmain(void)
{
    eSoc procID = Soc_None;
    eFormFactor formFactor = FormFactor_None;
    tVersion libVersion = {0, 0, 0};
    HANDLE threadHandle = NULL;
    HANDLE hGpio = NULL;
 
    /// Gets GPIO library version.
    Gpio_GetVersion(&libVersion);
    printf("GPIOLib Version %d.%d.%d\n", libVersion.Major, libVersion.Minor, libVersion.Build);
    /// Gets module family.
    formFactor = Cop_GetFormFactor();
    if (formFactor == FormFactor_Colibri)
    {
        printf("Colibri ");
    }
    else
    {
        printf("Apalis ");
    }
    /// Gets processor id.
    procID = Cop_GetSoc();
    switch (procID)
    {
        case Soc_PXA270:
            printf("PXA270 detected.\n");
            break;
        case Soc_PXA320:
            printf("PXA320 detected.\n");
            break; 
        case Soc_PXA300:
            printf("PXA300 detected.\n");
            break; 
        case Soc_PXA310:
            printf("PXA310 detected.\n");
            break; 
        case Soc_TEGRA2:
            printf("T20 detected.\n");
            break;
        case Soc_TEGRA3:
            printf("T30 detected.\n");
            break;
        case Soc_VF50:
            printf("VF50 detected.\n");
            break;
        case Soc_VF61:
            printf("VF61 detected.\n");
            break;
        case Soc_IMX6:
            printf("iMX6 detected.\n");
            break;
        default:
            printf("Processor type unknown.\n");
            getchar();
            return FALSE;
    }
    ///< Initializes GPIO library.
    hGpio = Gpio_Init(NULL);
    if (hGpio == NULL)
    {
        printf("Failed to initialize GPIO library.\n");
        getchar();
        return TRUE;
    }
    else
    {
        if (Gpio_Open(hGpio) == FALSE)
        {
            printf("Failed to configure GPIOs.\n");
            Gpio_Deinit(hGpio);
            getchar();
            return TRUE;
        }
    }

    ///< Configures GPIOs used for rows and columns.
    if (MatrixKeypadConfig(hGpio, ioColibriPin) == FALSE)
    {
        printf("Failed to configure matrix keypad.\n");
        /// De-initializes GPIO library.
        Gpio_Close(hGpio);
        Gpio_Deinit(hGpio);
        getchar();
        return TRUE;
    }

    /// Creates new thread to scan and display the key press.
    threadHandle = CreateThread(NULL, 0, (LPTHREAD_START_ROUTINE)MatrixKeypadScan, hGpio, 0, 0);

    printf("Press enter to stop the program and exit.\n");
    fflush(stdin);
    getchar();
    threadExit = TRUE;                      ///< To exit the thread.
    Sleep(AUTO_REPEAT_TIMEOUT_PER_COLUMN);  ///< Time to wait for thread termination.
    CloseHandle(threadHandle);              ///< Closes thread handle.
    /// De-initializes GPIO library.
    Gpio_Close(hGpio);
    Gpio_Deinit(hGpio);
    return TRUE;
}