/// @file           matrixkeypad.h
/// @copyright      Copyright (c) 2014 Toradex AG.
///                 [Software License Agreement]
/// $Author:        khv
/// $Date:          $ 2014-08-12 $
/// @brief:         File to support matrixkeypad.c

#ifndef _MATRIXKEYPAD_H_
#define _MATRIXKEYPAD_H_

/// Header files.
#include <windows.h>
#include "gpio.h"

/// Macros.
#define TOTAL_ROWS      4     ///< Total number of rows.
#define TOTAL_COLUMNS   4     ///< Total number of columns.

/// SODIMM pins as rows.
#define ROW1        98        ///< Iris connector X16 pin 13, used as GPIO.
#define ROW2        133       ///< Iris connector X16 pin 14, used as GPIO.
#define ROW3        103       ///< Iris connector X16 pin 15, used as GPIO.
#define ROW4        101       ///< Iris connector X16 pin 16, used as GPIO.

#define GET_ROW {ROW1, ROW2, ROW3, ROW4}

/// SODIMM pin as columns.
#define COL1        97        ///< Iris connector X16 pin 17, used as GPIO.
#define COL2        85        ///< Iris connector X16 pin 18, used as GPIO.
#define COL3        79        ///< Iris connector X16 pin 19, used as GPIO.
#define COL4        45        ///< Iris connector X16 pin 20, used as GPIO.

#define GET_COLUMN {COL1, COL2, COL3, COL4}

#define AUTO_REPEAT_TIMEOUT             100     ///< Time-out in ms to wait before scanning a key again.
#define KEY_STABLE_HIT_TIMEOUT           20     ///< Time-out in ms to ignore the bouncing of the keystroke.
#define AUTO_REPEAT_TIMEOUT_PER_COLUMN  ((DWORD)(AUTO_REPEAT_TIMEOUT / TOTAL_COLUMNS))

/// MatrixKeypadScan() will scan for key-press until threadExit value is TRUE.
extern volatile BOOL threadExit;

//******************************************************************************
/// Configures the GPIOs, used as input or output.
/// @param[in]    hGpio    Handle of GPIO library instance.
/// @param[in]    ioType   Specifies an IO pin.
/// @retval       TRUE     Success.
///               FALSE    Failure.
BOOL MatrixKeypadConfig(HANDLE hGpio, tIoType ioType);

//******************************************************************************
/// Scans for key pressed on matrix keypad. MatrixKeypadConfig() must be called before this.
/// @param[in]  hGpio    Handle of GPIO library instance.
/// @retval     TRUE     Success.
/// @retVal     FALSE    Failure, keypad configuration is not done.
BOOL MatrixKeypadScan(HANDLE hGpio);
 
#endif